@@ -1,4 +1,4 @@
-# $Id: Bucket.pm 2241 2007-03-25 05:20:15Z comdog $
+# $Id: Bucket.pm 2183 2007-02-27 23:24:59Z comdog $
 package Brick::Bucket;
 use strict;
 
@@ -10,15 +10,14 @@ use Carp;
 
 use Brick::Constraints;
 
-foreach my $package ( qw(Numbers Regexes Strings Dates General 
-	Composers Filters Selectors Files) )
+foreach my $package ( qw(Numbers Regexes Strings Dates General Composers Filters Selectors) )
 	{
 	# print STDERR "Requiring $package\n";
 	eval "require Brick::$package";
 	print STDERR $@ if $@;
 	}
 
-$VERSION = sprintf "1.%04d", q$Revision: 2241 $ =~ m/ (\d+) /xg;
+$VERSION = sprintf "1.%04d", q$Revision: 2183 $ =~ m/ (\d+) /xg;
 
 =head1 NAME
 
@@ -57,8 +56,7 @@ sub _init
 	{
 	my $self = shift;
 
-	$self->{_names}        = {};
-	$self->{_field_labels} = {};
+	$self->{_names} = {};
 	}
 
 =item entry_class
@@ -84,8 +82,6 @@ sub entry_class { __PACKAGE__ . "::Entry"; }
 
 =item add_to_bucket( HASHREF )
 
-=item add_to_pool # DEPRECATED
-
 You can pass these entries in the HASHREF:
 
 	code        - the coderef to add to the bucket
@@ -115,7 +111,7 @@ sub add_to_pool { croak "add_to_pool is now add_to_bucket" }
 sub add_to_bucket
 	{
 	require B;
-	my @caller = __caller_chain_as_list();
+	my @caller = main::__caller_chain_as_list();
 	# print STDERR Data::Dumper->Dump( [\@caller],[qw(caller)] );
 	my( $bucket, $setup ) = @_;
 
@@ -205,7 +201,7 @@ sub get_from_bucket
 	return exists $bucket->{$sub} ? $bucket->{$sub} : ();
 	}
 
-=item get_brick_by_name( NAME )
+=item get_from_bucket_by_name( NAME )
 
 Gets the code references for the bricks with the name NAME. Since
 bricks don't have to have a unique name, it might return more than
@@ -286,77 +282,6 @@ sub dump_bucket
 
 =back
 
-=head2 Field labels
-
-The bucket can store a dictionary that maps field names to arbitrary
-strings. This way, a brick can translate and input parameter name
-(e.g. a CGI input field name) into a more pleasing string for humans
-for its error messages. By providing methods in the bucket class,
-every brick has a chance to call them.
-
-=over 4
-
-=item use_field_labels( HASHREF )
-
-Set the hash that C<get_field_label> uses to map field names to 
-field labels.
-
-This method croaks if its argument isn't a hash reference. 
-
-=cut
-
-sub use_field_labels
-	{
-	croak "Not a hash reference!" unless UNIVERSAL::isa( $_[1], ref {} );
-	$_[0]->{_field_labels} = { %{$_[1]} };	
-	}
-
-=item get_field_label( FIELD )
-
-Retrieve the label for FIELD.
-
-=cut
-
-sub get_field_label
-	{
-	no warnings 'uninitialized';
-	$_[0]->{_field_labels}{ $_[1] };
-	}
-	
-=item set_field_label( FIELD, VALUE )
-
-Set the label for FIELD to VALUE. It returns VALUE.
-
-=cut
-
-sub set_field_label
-	{
-	$_[0]->{_field_labels}{ $_[1] } = $_[2];
-	}
-
-sub __caller_chain_as_list
-	{
-	my $level = 0;
-	my @Callers = ();
-
-	while( 1 )
-		{
-		my @caller = caller( ++$level );
-		last unless @caller;
-
-		push @Callers, {
-			level   => $level,
-			package => $caller[0],
-			'sub'   => $caller[3] =~ m/(?:.*::)?(.*)/,
-			};
-		}
-
-	#print STDERR Data::Dumper->Dump( [\@Callers], [qw(callers)] ), "-" x 73, "\n";
-	@Callers;
-	}
-	
-=back
-
 =head1 Brick::Bucket::Entry
 
 =cut
@@ -504,8 +429,6 @@ sub add_bit
 
 =item $entry->dump
 
-Print a text version of the entry.
-
 =cut
 
 sub dump
@@ -515,16 +438,6 @@ sub dump
 	Data::Dumper->Dump( [ $_[0]->entry( $_[1] ) ], [ "$_[1]" ] )
 	}
 
-=item $entry->applies_to_fields
-
-Return a list of fields the brick applies to.
-
-I don't think I've really figured this out, but the composers should be
-the ones to figure it out and add this stuff to the information that the
-bucket tracks.
-
-=cut
-
 sub applies_to_fields
 	{
 	my( $class, $sub, @fields ) = @_;
@@ -536,6 +449,26 @@ sub applies_to_fields
 		}
 	}
 
+sub main::__caller_chain_as_list
+	{
+	my $level = 0;
+	my @Callers = ();
+
+	while( 1 )
+		{
+		my @caller = caller( ++$level );
+		last unless @caller;
+
+		push @Callers, {
+			level   => $level,
+			package => $caller[0],
+			'sub'   => $caller[3] =~ m/(?:.*::)?(.*)/,
+			};
+		}
+
+	#print STDERR Data::Dumper->Dump( [\@Callers], [qw(callers)] ), "-" x 73, "\n";
+	@Callers;
+	}
 
 =back
 
