@@ -1,9 +1,9 @@
-# $Id: Constraints.pm 2264 2007-05-09 17:06:24Z comdog $
+# $Id: Constraints.pm 2183 2007-02-27 23:24:59Z comdog $
 package Brick::Constraints;
 use base qw(Exporter);
 use vars qw($VERSION);
 
-$VERSION = sprintf "1.%04d", q$Revision: 2264 $ =~ m/ (\d+) /xg;
+$VERSION = sprintf "1.%04d", q$Revision: 2183 $ =~ m/ (\d+) /xg;
 
 package Brick::Bucket;
 use strict;
@@ -40,7 +40,7 @@ sub __make_constraint # may need to change name to make generic
 
 	$setup ||= {};
 
-	my @callers = $bucket->__caller_chain_as_list();
+	my @callers = main::__caller_chain_as_list();
 
 	#print STDERR Data::Dumper->Dump( [\@callers], [qw(callers)] ); use Data::Dumper;
 
@@ -49,9 +49,8 @@ sub __make_constraint # may need to change name to make generic
 		carp "$callers[1]{'sub'} called from sub with leading underscore. Are you sure you want that?";
 		}
 
-	my $name = $setup->{name} || $callers[1]{'sub'} || 'Anonymous';
-	print STDERR "Constraint name is $name\n" if $ENV{DEBUG};
-	
+	my $name = $setup->{name} || $callers[-1]{'sub'} || 'Anonymous';
+
 	unless(
 		eval { $validator->isa( ref sub {} ) }    ||
 		UNIVERSAL::isa( $validator, ref sub {} )
@@ -65,7 +64,7 @@ sub __make_constraint # may need to change name to make generic
 		description => "Brick constraint sub for $name",
 
 		code        => sub {
-			my $input_hash = shift;
+		my $input_hash = shift;
 
 			my $result = eval{ $validator->( $input_hash ) };
 			die if $@;
